@@ -193,8 +193,7 @@ class NodeReadAPI(Generic[T_DomainModel, T_DomainModelList], ABC):
     ) -> T_DomainModelList:
         executor = self._build(filter_, limit, retrieve_connections, sort)
         results = executor.execute_query(self._client, remove_not_connected=False)
-        unpack_edges: Literal["skip", "identifier"] = "identifier" if retrieve_connections == "identifier" else "skip"
-        unpacked = QueryUnpacker(results, edges=unpack_edges).unpack()
+        unpacked = QueryUnpacker(results, edges="skip").unpack()
         item_list = instantiate_classes(self._class_type, unpacked, context)
         return self._class_list(item_list)
 
@@ -215,10 +214,7 @@ class NodeReadAPI(Generic[T_DomainModel, T_DomainModelList], ABC):
         self._last_cursors = cursors
         executor = self._build(filter_, limit, retrieve_connections, sort, chunk_size)
         for batch_results in executor.iterate(self._client, remove_not_connected=False, init_cursors=cursors):
-            unpack_edges: Literal["skip", "identifier"] = (
-                "identifier" if retrieve_connections == "identifier" else "skip"
-            )
-            unpacked = QueryUnpacker(batch_results, edges=unpack_edges).unpack()
+            unpacked = QueryUnpacker(batch_results, edges="skip").unpack()
             yield self._class_list(
                 instantiate_classes(self._class_type, unpacked, "iterate"), cursors=batch_results._cursors
             )
