@@ -25,15 +25,18 @@ from typing import (
 import pandas as pd
 from cognite.client import data_modeling as dm
 from cognite.client.data_classes import (
-    TimeSeriesWrite,
-    TimeSeriesWriteList,
+    FileMetadata,
+    FileMetadataList,
     FileMetadataWrite,
     FileMetadataWriteList,
+    Sequence as CogniteSequence,
+    SequenceList,
     SequenceWrite,
     SequenceWriteList,
+    TimeSeries,
     TimeSeriesList,
-    FileMetadataList,
-    SequenceList,
+    TimeSeriesWrite,
+    TimeSeriesWriteList,
 )
 from cognite.client.data_classes.data_modeling.instances import (
     Instance,
@@ -917,9 +920,11 @@ def as_write_args(model: DomainModel | GraphQLCore | DomainRelation | GraphQLExt
 
 def as_write_value(value: Any) -> Any:
     if isinstance(value, DomainModel | GraphQLCore | GraphQLExternal):
-        return as_write_args(value)
+        return value.as_write() if hasattr(value, "as_write") else as_write_args(value)
     elif isinstance(value, Sequence) and not isinstance(value, str):
         return [as_write_value(item) for item in value]
+    elif isinstance(value, TimeSeries | FileMetadata | CogniteSequence):
+        return value.as_write()
     return value
 
 
